/*
 * Functions for setting up the ESP8266 WLAN module.
 *
 * (C) 2016 General Overnight  <generalovernight.wordpress.com>
 *
 * This is Free Software available under the GNU General Public License (GPL).
 *
 * $Id: wlansetup.ino,v 1.1 2016-01-31 08:55:31 manolo Exp $
 */

int espConfig()
{
  int rc = 0;

  /* increase the timeout for resetting the ESP */
  esp8266.setTimeout(DEFTO * 3);
  /* send a reset command to the ESP8266 and wait for the string "ready" */
  rc |= runATcmd("+RST", "ready");

  /* configure as a WLAN access point */
  if (!configAP(SSID, PSK)) {
    esp8266.setTimeout(DEFTO);
    dbg(LVL_NOTE, "WiFi Access point successfully set up with config:");
    dbg(LVL_NOTE, runATcmd("+CIFSR", 3));
  } else {
    rc |= 0x2;
  }

  rc |= (runATcmd("+CIPMODE=0", "OK")) << 3;
  rc |= (runATcmd("+CIPMUX=0", "OK")) << 2;
  esp8266.setTimeout(DEFTO);

  /* finally light up the onboard LED if everything went OK */
  if (0 == rc) {
    digitalWrite(LED_BUILTIN, HIGH);
  } else {
    dbg("ESP config error: " + String(rc));
  }

  return rc;
}


int configAP(String ssid, String psk)
{
  int rc = 0;

  /* increase the timeout, AP setup commands may take significantly more
   * time to finish.
   */
  esp8266.setTimeout(DEFTO * 2);
  rc |= (runATcmd("+CWMODE=2", "OK"));
  /* Set up WiFi AP with parameters (in RAM only):
   *   SSID, PSK, channel number (1-14), encryption index (0-4)
   */
  rc |= (runATcmd("+CWSAP_CUR=\""+String(ssid)+"\",\""+String(psk)+"\",1,3",
                 "OK"));
  /* Set the IP address for the AP (in RAM only) */
  rc |= (runATcmd("+CIPAP_CUR=\"" SRCIP "\"", "OK"));
  /* Reset the timeout value */
  esp8266.setTimeout(DEFTO);

  return rc;
}

int configUDP(String port)
{
  int rc = 0;

  esp8266.setTimeout(DEFTO + DEFTO / 2);
  rc |= !runATcmd("+CIPMODE=0", "OK");
  rc |= !runATcmd("+CIPMUX=0", "OK");
  /* Start an UDP Broadcast server */
  rc |= !runATcmd("+CIPSTART=\"UDP\",\"" DSTIP "\"," + port, "OK");
  esp8266.setTimeout(DEFTO);

  return rc;
}


// Local Variables:
// mode: c++
// End:
